==> kdebase-workspace-4.2.2_1.tbz: lib/KDE4Workspace/cmake/KDE4WorkspaceLibraryTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "release".
#----------------------------------------------------------------

# Commands may need to know the format version.
SET(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDE4Workspace__kephal" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__kephal APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__kephal PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "/usr/local/lib/qt4/libQtDBus.so;/usr/local/lib/qt4/libQtCore.so;-pthread;/usr/local/lib/qt4/libQtGui.so"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkephal.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkephal.so.5"
  )

# Import target "KDE4Workspace__plasmaclock" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__plasmaclock APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__plasmaclock PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__plasma;KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libplasmaclock.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libplasmaclock.so.5"
  )

# Import target "KDE4Workspace__solidcontrolifaces" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__solidcontrolifaces APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__solidcontrolifaces PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libsolidcontrolifaces.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libsolidcontrolifaces.so.5"
  )

# Import target "KDE4Workspace__solidcontrol" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__solidcontrol APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__solidcontrol PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore;KDE4__solid;KDE4Workspace__solidcontrolifaces"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libsolidcontrol.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libsolidcontrol.so.5"
  )

# Import target "KDE4Workspace__taskmanager" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__taskmanager APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__taskmanager PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui;KDE4Workspace__kephal"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libtaskmanager.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libtaskmanager.so.5"
  )

# Import target "KDE4Workspace__lsofui" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__lsofui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__lsofui PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/liblsofui.so.5.0.1"
  IMPORTED_SONAME_RELEASE "liblsofui.so.5"
  )

# Import target "KDE4Workspace__processcore" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__processcore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__processcore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libprocesscore.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libprocesscore.so.5"
  )

# Import target "KDE4Workspace__processui" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__processui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__processui PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui;KDE4Workspace__processcore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libprocessui.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libprocessui.so.5"
  )

# Import target "KDE4Workspace__kworkspace" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__kworkspace APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__kworkspace PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkworkspace.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkworkspace.so.5"
  )

# Import target "KDE4Workspace__nepomukquery" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__nepomukquery APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__nepomukquery PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libnepomukquery.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libnepomukquery.so.5"
  )

# Import target "KDE4Workspace__nepomukqueryclient" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__nepomukqueryclient APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__nepomukqueryclient PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4Workspace__nepomukquery;KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libnepomukqueryclient.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libnepomukqueryclient.so.5"
  )

# Import target "KDE4Workspace__kscreensaver" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__kscreensaver APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__kscreensaver PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkscreensaver.so.5.0.0"
  IMPORTED_SONAME_RELEASE "libkscreensaver.so.5"
  )

# Import target "KDE4Workspace__kdecorations" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__kdecorations APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__kdecorations PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4Workspace__kephal"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdecorations.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkdecorations.so.5"
  )

# Import target "KDE4Workspace__kwineffects" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__kwineffects APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__kwineffects PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui;KDE4Workspace__kephal"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "/usr/local/lib/libGL.so"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkwineffects.so.1.0.0"
  IMPORTED_SONAME_RELEASE "libkwineffects.so.1"
  )

# Import target "KDE4Workspace__ksgrd" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__ksgrd APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__ksgrd PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libksgrd.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libksgrd.so.5"
  )

# Import target "KDE4Workspace__weather_ion" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__weather_ion APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__weather_ion PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui;KDE4__kio;KDE4__plasma"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libweather_ion.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libweather_ion.so.5"
  )

# Commands beyond this point should not need to know the version.
SET(CMAKE_IMPORT_FILE_VERSION)

==> kdebase-workspace-4.3.1.tbz: lib/KDE4Workspace/cmake/KDE4WorkspaceLibraryTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "release".
#----------------------------------------------------------------

# Commands may need to know the format version.
SET(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDE4Workspace__kephal" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__kephal APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__kephal PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "/usr/local/lib/qt4/libQtDBus.so;/usr/local/lib/qt4/libQtCore.so;-pthread;/usr/local/lib/qt4/libQtGui.so"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkephal.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkephal.so.5"
  )

# Import target "KDE4Workspace__plasmaclock" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__plasmaclock APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__plasmaclock PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__plasma;KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libplasmaclock.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libplasmaclock.so.5"
  )

# Import target "KDE4Workspace__solidcontrolifaces" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__solidcontrolifaces APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__solidcontrolifaces PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libsolidcontrolifaces.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libsolidcontrolifaces.so.5"
  )

# Import target "KDE4Workspace__solidcontrol" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__solidcontrol APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__solidcontrol PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore;KDE4__solid;KDE4Workspace__solidcontrolifaces"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libsolidcontrol.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libsolidcontrol.so.5"
  )

# Import target "KDE4Workspace__taskmanager" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__taskmanager APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__taskmanager PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui;KDE4__kio;KDE4Workspace__kephal"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libtaskmanager.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libtaskmanager.so.5"
  )

# Import target "KDE4Workspace__lsofui" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__lsofui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__lsofui PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/liblsofui.so.5.0.1"
  IMPORTED_SONAME_RELEASE "liblsofui.so.5"
  )

# Import target "KDE4Workspace__processcore" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__processcore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__processcore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libprocesscore.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libprocesscore.so.5"
  )

# Import target "KDE4Workspace__processui" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__processui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__processui PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui;KDE4Workspace__processcore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libprocessui.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libprocessui.so.5"
  )

# Import target "KDE4Workspace__kworkspace" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__kworkspace APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__kworkspace PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui;KDE4__plasma"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkworkspace.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkworkspace.so.5"
  )

# Import target "KDE4Workspace__nepomukquery" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__nepomukquery APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__nepomukquery PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libnepomukquery.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libnepomukquery.so.5"
  )

# Import target "KDE4Workspace__nepomukqueryclient" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__nepomukqueryclient APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__nepomukqueryclient PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4Workspace__nepomukquery;KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libnepomukqueryclient.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libnepomukqueryclient.so.5"
  )

# Import target "KDE4Workspace__kscreensaver" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__kscreensaver APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__kscreensaver PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkscreensaver.so.5.0.0"
  IMPORTED_SONAME_RELEASE "libkscreensaver.so.5"
  )

# Import target "KDE4Workspace__kdecorations" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__kdecorations APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__kdecorations PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4Workspace__kephal"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdecorations.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkdecorations.so.5"
  )

# Import target "KDE4Workspace__kwineffects" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__kwineffects APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__kwineffects PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui;KDE4__plasma;KDE4Workspace__kephal"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "/usr/local/lib/libGL.so"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkwineffects.so.1.0.0"
  IMPORTED_SONAME_RELEASE "libkwineffects.so.1"
  )

# Import target "KDE4Workspace__ksgrd" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__ksgrd APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__ksgrd PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libksgrd.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libksgrd.so.5"
  )

# Import target "KDE4Workspace__time_solar" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__time_solar APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__time_solar PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdecore;KDE4__plasma"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libtime_solar.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libtime_solar.so.5"
  )

# Import target "KDE4Workspace__weather_ion" for configuration "release"
SET_PROPERTY(TARGET KDE4Workspace__weather_ion APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDE4Workspace__weather_ion PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui;KDE4__kio;KDE4__plasma"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libweather_ion.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libweather_ion.so.5"
  )

# Commands beyond this point should not need to know the version.
SET(CMAKE_IMPORT_FILE_VERSION)
